==> haskell-conduit-extra-1.3.1.1-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.3.1.1
id: conduit-extra-1.3.1.1-7XA4NerKXBpBM0lrNiOBvC
key: conduit-extra-1.3.1.1-7XA4NerKXBpBM0lrNiOBvC
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
abi: 10d67fd13d51c9723b22666571429e24
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib
import-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-extra-1.3.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-extra-1.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/conduit-extra-1.3.1.1
hs-libraries: HSconduit-extra-1.3.1.1-7XA4NerKXBpBM0lrNiOBvC
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-Hp9wSvoIvGH1D2bMBRqJC
    directory-1.3.3.0 filepath-1.4.2.1
    network-2.8.0.0-KwUidTBebCCJ8Fjkxwovi
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b process-1.6.5.0
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c stm-2.5.0.0
    streaming-commons-0.2.1.1-8vrO993osU6EG9wXe6jaVA text-1.2.3.1
    transformers-0.5.6.2 typed-process-0.2.4.0-AKSwx7bfrQWHZVrpHcUgqK
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.3.1.1-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.3.1.1
id: conduit-extra-1.3.1.1-BpNAtWN1v251tAneLnGOdO
key: conduit-extra-1.3.1.1-BpNAtWN1v251tAneLnGOdO
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
abi: 79e8a1c967e2c3cb9acd71f92335c58e
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Foldl Data.Conduit.Lazy Data.Conduit.Network
    Data.Conduit.Network.UDP Data.Conduit.Network.Unix
    Data.Conduit.Process Data.Conduit.Process.Typed Data.Conduit.Text
    Data.Conduit.Zlib
import-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-extra-1.3.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/conduit-extra-1.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/conduit-extra-1.3.1.1
hs-libraries: HSconduit-extra-1.3.1.1-BpNAtWN1v251tAneLnGOdO
depends:
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG
    attoparsec-0.13.2.2-EdUct2wsQri8X0bjC24wTV base-4.12.0.0
    bytestring-0.10.8.2 conduit-1.3.1.1-GP6MsgQ2BS48W03o5Iyugz
    directory-1.3.3.0 filepath-1.4.2.1
    network-2.8.0.0-KwUidTBebCCJ8Fjkxwovi
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b process-1.6.5.0
    resourcet-1.2.2-DSV6hnFiraKK5yk15oWe4c stm-2.5.0.0
    streaming-commons-0.2.1.1-8vrO993osU6EG9wXe6jaVA text-1.2.3.1
    transformers-0.5.6.2 typed-process-0.2.4.1-beWb2K35BN9E1vzafS6o7
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
